Runtime class and read-construct support for device sample values.
Structs
- Device
Sample Value - Runtime object wrapping a device sample expression.
- Device
Stream Base Lib - Host-registered library that installs the device stream base class.
Functions
- device_
sample_ class_ symbol - Returns the read-construct class symbol for device sample values.
- device_
stream_ base_ exports - Export records advertised by
DeviceStreamBaseLib. - device_
stream_ base_ manifest_ symbol - Returns the manifest id for the device stream base library.
- install_
device_ stream_ base - Installs the device stream base into a context exactly once.